import React from "react";
import {
  Modal,
  ModalContent,
  ModalHeader,
  ModalBody,
  ModalFooter,
  Button,
  useDisclosure,
  Input,
  Avatar,
} from "@nextui-org/react";
import { AiFillPlusSquare } from "react-icons/ai";
import { FiPlus } from "react-icons/fi";
import { BsFolderFill } from "react-icons/bs";
import { useForm } from "react-hook-form";
import { doFetch } from "@/lib/doFetch";
import UploadImage from "./UploadImage";

export default function AddFolder({ refresh, parentId, type }) {
  const { isOpen, onOpen, onOpenChange } = useDisclosure();
  const { register, handleSubmit, control, setValue } = useForm();

  const handleButtonClick = async (close) => {
    // 手动触发表单提交
    handleSubmit(onSubmit)();
    close();
  };

  const onSubmit = async (data) => {
    await doFetch({
      url: "/api/folder",
      params: { ...data, parentId: parentId ?parseInt(parentId): null },
    });
    await refresh();
  };

  return (
    <>
      {type === "icon" ? (
        <Button
          isIconOnly
          color="primary"
          variant="faded"
          aria-label="Take a add"
          onPress={onOpen}
        >
            <BsFolderFill style={{ fontSize: "20px" }} />
        </Button>
      ) : (
        <Button
          radius="full"
          className="bg-gradient-to-tr from-pink-500 to-yellow-500 text-white shadow-lg mb-4"
          onPress={onOpen}
        >
          <FiPlus />
          添加文件夹
        </Button>
      )}

      <Modal
        isOpen={isOpen}
        backdrop={"blur"}
        onOpenChange={onOpenChange}
        motionProps={{
          variants: {
            enter: {
              y: 0,
              opacity: 1,
              transition: {
                duration: 0.3,
                ease: "easeOut",
              },
            },
            exit: {
              y: -20,
              opacity: 0,
              transition: {
                duration: 0.2,
                ease: "easeIn",
              },
            },
          },
        }}
      >
        <ModalContent>
          {(onClose) => (
            <>
              <ModalHeader className="flex flex-col gap-1">
                添加文件夹
              </ModalHeader>
              <ModalBody>
                <form action="">
                  <input type="hidden" {...register("poster")} />
                  <div className="flex justify-center items-center flex-col mb-8">
                    <UploadImage
                      control={control}
                      setValue={setValue}
                    ></UploadImage>
                  </div>

                  <Input
                    isRequired
                    isClearable
                    type="text"
                    label="文件夹"
                    name="name"
                    {...register("name", { required: true, maxLength: 20 })}
                  />
                </form>
              </ModalBody>
              <ModalFooter>
                <Button color="danger" variant="light" onPress={onClose}>
                  取消
                </Button>
                <Button
                  color="primary"
                  onPress={() => {
                    handleButtonClick(onClose);
                  }}
                >
                  提交
                </Button>
              </ModalFooter>
            </>
          )}
        </ModalContent>
      </Modal>
    </>
  );
}
